@@ -1131,7 +1131,8 @@ assertProcedureSource(DECL_LD SourceFile sf, Procedure proc, Clause clause)
     if ( (cref = reload->current_clause) )
     { ClauseRef cref2;
 
-      if ( equal_clause(cref->value.clause, clause) )
+      if ( equal_clause(cref->value.clause, clause) &&
+	   isoff(cref->value.clause, CL_ERASED) )
       { DEBUG(MSG_RECONSULT_CLAUSE,
 	      Sdprintf("  Keeping clause %d\n",
 		       clauseNo(cref->value.clause, reload->generation)));
@@ -1253,7 +1254,10 @@ setAttrProcedureSource(DECL_LD SourceFile sf, Procedure proc,
 
 static void
 check_ssu(p_reload *r)
-{ GET_LD
+{
+#ifdef O_PLMT
+  GET_LD
+#endif
   Definition def = r->predicate;
   ClauseRef cref;
   int errors = 0;
@@ -1456,7 +1460,10 @@ delete_old_predicate(SourceFile sf, Procedure proc)
   size_t deleted;
 
   if ( def->functor->functor == FUNCTOR_dtabled2 )
-  { GET_LD
+  {
+#ifdef O_PLMT
+    GET_LD
+#endif
     ClauseRef c;
 
     acquire_def(def);
